


04/16/93 E. Correia
WK#:581       MV#:3c
Breitkopf & H\3artel, vol. 13 
Clarinet Quintet
Trio II
Viola
1 0 
Group memberships: sound, score
sound: part 4 of 5
score: part 4 of 5
$  K:3   Q:2   T:3/4   C:13
rest   2        q
measure 1
rest   2        q
C#4    2        q     d        p
C#4    2        q     d
measure 2
rest   2        q
B3     2        q     u
B3     2        q     u
measure 3
rest   2        q
B3     2        q     u
B3     2        q     u
measure 4
rest   2        q
A3     2        q     u
A3     2        q     u
measure 5
rest   2        q
C#4    2        q     d
C#4    2        q     d
measure 6
B3     2        q     u
rest   2        q
E4     2        q     d        (
measure 7
D4     4        h     d
E4     2        q     d
measure 8
D4     4        h     d        )
rest   2        q
measure 9
rest   6
measure 10
rest   6
measure 11
E3     6-       h.    u        -
measure 12
E3     2        q     u
rest   2        q
mheavy4         :||:
/END
